==> orthanc_0.7.6%2Bdfsg.orig.tar.xz: Orthanc-0.7.6/OrthancServer/Internals/DicomImageDecoder.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2014 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include <dcmtk/dcmdata/dcfilefo.h>

#include "../../Core/ImageFormats/ImageBuffer.h"

namespace Orthanc
{
  class DicomImageDecoder
  {
  private:
    class ImageSource;

    static void DecodeUncompressedImageInternal(ImageBuffer& target,
                                                DcmDataset& dataset,
                                                unsigned int frame);

    static bool IsPsmctRle1(DcmDataset& dataset);

    static void SetupImageBuffer(ImageBuffer& target,
                                 DcmDataset& dataset);

    static bool DecodePsmctRle1(std::string& output,
                                DcmDataset& dataset);

    static bool IsUncompressedImage(const DcmDataset& dataset);

    static bool IsJpegLossless(const DcmDataset& dataset);

    static void DecodeUncompressedImage(ImageBuffer& target,
                                        DcmDataset& dataset,
                                        unsigned int frame);

#if ORTHANC_JPEG_LOSSLESS_ENABLED == 1
    static void DecodeJpegLossless(ImageBuffer& target,
                                   DcmDataset& dataset,
                                   unsigned int frame);
#endif

  public:
    static bool Decode(ImageBuffer& target,
                       DcmDataset& dataset,
                       unsigned int frame);

    static bool DecodeAndTruncate(ImageBuffer& target,
                                  DcmDataset& dataset,
                                  unsigned int frame,
                                  PixelFormat format);

    static bool DecodePreview(ImageBuffer& target,
                              DcmDataset& dataset,
                              unsigned int frame);
  };
}

==> orthanc_0.9.4%2Bdfsg.orig.tar.xz: Orthanc-0.9.4/OrthancServer/Internals/DicomImageDecoder.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2015 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include <dcmtk/dcmdata/dcfilefo.h>

#include "../../Core/Images/ImageBuffer.h"

namespace Orthanc
{
  class DicomImageDecoder
  {
  private:
    class ImageSource;

    static void DecodeUncompressedImageInternal(ImageBuffer& target,
                                                DcmDataset& dataset,
                                                unsigned int frame);

    static bool IsPsmctRle1(DcmDataset& dataset);

    static void SetupImageBuffer(ImageBuffer& target,
                                 DcmDataset& dataset);

    static bool IsUncompressedImage(const DcmDataset& dataset);

    static void DecodeUncompressedImage(ImageBuffer& target,
                                        DcmDataset& dataset,
                                        unsigned int frame);

#if ORTHANC_JPEG_LOSSLESS_ENABLED == 1
    static void DecodeJpegLossless(ImageBuffer& target,
                                   DcmDataset& dataset,
                                   unsigned int frame);
#endif

  public:
    static bool Decode(ImageBuffer& target,
                       DcmDataset& dataset,
                       unsigned int frame);

    static bool DecodeAndTruncate(ImageBuffer& target,
                                  DcmDataset& dataset,
                                  unsigned int frame,
                                  PixelFormat format,
                                  bool allowColorConversion);

    static bool DecodePreview(ImageBuffer& target,
                              DcmDataset& dataset,
                              unsigned int frame);
  };
}
